@@ -1,10 +1,13 @@
+from typing import Optional
+from typing import Union
+
 from ice.trace import TracedABC
 
-Stop = str | list[str] | None
+Stop = Optional[Union[str, list[str]]]
 
 
 class Agent(TracedABC):
-    label: str | None = None
+    label: Optional[str] = None
 
     async def complete(
         self,
@@ -22,9 +25,9 @@ class Agent(TracedABC):
         *,
         prompt: str,
         choices: tuple[str, ...],
-        default: str | None = None,
+        default: Optional[str] = None,
         verbose: bool = False,
-    ) -> tuple[dict[str, float], str | None]:
+    ) -> tuple[dict[str, float], Optional[str]]:
         raise NotImplementedError
 
     # Methods below may be deprecated in the future:
@@ -35,7 +38,7 @@ class Agent(TracedABC):
         context: str,
         question: str,
         verbose: bool = False,
-        default: float | None = None,
+        default: Optional[float] = None,
     ) -> float:
         raise NotImplementedError
 
