@@ -1,3 +1,5 @@
+from typing import Optional
+
 from ice.agents.base import Agent
 from ice.agents.base import Stop
 from ice.environment import env
@@ -39,9 +41,9 @@ class HumanAgent(Agent):
         *,
         prompt: str,
         choices: tuple[str, ...],
-        default: str | None = None,
+        default: Optional[str] = None,
         verbose: bool = False,
-    ) -> tuple[dict[str, float], str | None]:
+    ) -> tuple[dict[str, float], Optional[str]]:
         choice = await env().select(
             prompt=prompt, choices=list(choices), default=default
         )
