@@ -1,4 +1,6 @@
 from collections.abc import Mapping
+from typing import Optional
+from typing import Union
 
 import httpx
 
@@ -41,14 +43,18 @@ def log_attempt_number(retry_state):
         )
 
 
+def make_headers() -> dict[str, str]:
+    headers = {
+        "Content-Type": "application/json",
+        "Authorization": f"Bearer {settings.OPENAI_API_KEY}",
+    }
+    if settings.OPENAI_ORG_ID:
+        headers["OpenAI-Organization"] = settings.OPENAI_ORG_ID
+    return headers
+
+
 RETRYABLE_STATUS_CODES = {408, 429, 502, 503, 504}
 OPENAI_BASE_URL = "https://api.openai.com/v1"
-OPENAI_DEFAULT_HEADERS = {
-    "Content-Type": "application/json",
-    "Authorization": f"Bearer {settings.OPENAI_API_KEY}",
-}
-if settings.OPENAI_ORG_ID:
-    OPENAI_DEFAULT_HEADERS["OpenAI-Organization"] = settings.OPENAI_ORG_ID
 
 
 def is_retryable_HttpError(e: BaseException) -> bool:
@@ -100,8 +106,8 @@ def raise_if_too_long_error(prompt: object, response: Response) -> None:
     after=log_attempt_number,
 )
 async def _post(
-    endpoint: str, json: dict, timeout: float | None = None, cache_id: int = 0
-) -> dict | TooLongRequestError:
+    endpoint: str, json: dict, timeout: Optional[float] = None, cache_id: int = 0
+) -> Union[dict, TooLongRequestError]:
     """Send a POST request to the OpenAI API and return the JSON response."""
     cache_id  # unused
 
@@ -109,8 +115,8 @@ async def _post(
         response = await client.post(
             f"{OPENAI_BASE_URL}/{endpoint}",
             json=json,
-            headers=OPENAI_DEFAULT_HEADERS,
-            timeout=timeout,
+            headers=make_headers(),
+            timeout=timeout or 60,
         )
         if response.status_code == 429:
             raise RateLimitError(response)
@@ -133,13 +139,13 @@ def get_davinci_equivalent_tokens(response: dict) -> int:
 @trace
 async def openai_complete(
     prompt: str,
-    stop: str | None = "\n",
+    stop: Optional[str] = "\n",
     top_p: float = 1,
     temperature: float = 0,
     model: str = "text-davinci-002",
     max_tokens: int = 256,
-    logprobs: int | None = None,
-    logit_bias: Mapping[str, int | float] | None = None,
+    logprobs: Optional[int] = None,
+    logit_bias: Optional[Mapping[str, Union[int, float]]] = None,
     n: int = 1,
     echo: bool = False,
     cache_id: int = 0,  # for repeated non-deterministic sampling using caching
@@ -158,9 +164,8 @@ async def openai_complete(
     }
     if logit_bias:
         params["logit_bias"] = logit_bias  # type: ignore[assignment]
-
     response = await _post("completions", json=params, cache_id=cache_id)
     if isinstance(response, TooLongRequestError):
         raise response
-    add_fields(davinci_equivalent_tokens=str(get_davinci_equivalent_tokens(response)))
+    add_fields(davinci_equivalent_tokens=get_davinci_equivalent_tokens(response))
     return response
