@@ -1,17 +1,21 @@
 import httpx
 
+from fvalues import F
+
 from ice.recipe import recipe
 
 
 def make_search_result_prompt(context: str, question: str) -> str:
-    return f"""
+    return F(
+        f"""
 Search results from Google: "{context}"
 
 Answer the following question, using the search results if helpful:
 
 Question: "{question}"
 Answer: "
-""".strip()
+"""
+    ).strip()
 
 
 async def search(query: str) -> dict:
@@ -32,9 +36,9 @@ def render_results(data: dict) -> str:
         snippet = result.get("snippet")
         if not title or not link or not snippet:
             continue
-        results.append(f"{title}\n{link}\n{snippet}\n")
+        results.append(F(f"{title}\n{link}\n{snippet}\n"))
 
-    return "\n".join(results)
+    return F("\n").join(results)
 
 
 async def answer_by_search(
