@@ -1,3 +1,5 @@
+from fvalues import F
+
 from ice.recipe import recipe
 
 
@@ -7,14 +9,16 @@ DEFAULT_QUESTION = "What is happening on 9/9/2022?"
 
 
 def make_qa_prompt(context: str, question: str) -> str:
-    return f"""
+    return F(
+        f"""
 Background text: "{context}"
 
 Answer the following question about the background text above:
 
 Question: "{question}"
 Answer: "
-""".strip()
+"""
+    ).strip()
 
 
 async def answer(
