@@ -1,12 +1,16 @@
+from fvalues import F
+
 from ice.recipe import recipe
 
 
 def make_qa_prompt(question: str) -> str:
-    return f"""Answer the following question:
+    return F(
+        f"""Answer the following question:
 
 Question: "{question}"
 Answer: "
-""".strip()
+"""
+    ).strip()
 
 
 async def answer(question: str = "What is happening on 9/9/2022?"):
